PALM-meteo: palmmeteo.library.PalmPhysics Class Reference

PALM-meteo

Public Member Functions | Static Public Attributes | List of all members
palmmeteo.library.PalmPhysics Class Reference
Inheritance diagram for palmmeteo.library.PalmPhysics:
[legend]

## Public Member Functions
def | barom_lapse0_pres (cls, p0, gp, gp0, t0)
def | barom_lapse0_gp (cls, gp0, p, p0, t0)
def | barom_ptn_pres (cls, p0, z, t0)
def | exner (cls, p)
def | exner_inv (cls, p)

## Static Public Attributes
float | g = 9.81
int | c_p = 1005.
int | r_d = 287.
int | p0 = 1e5
float | sigma_sb = 5.67037e-08
int | d_p0 = 1e-5
float | g_d_cp = g / c_p
int | cp_d_rd = c_p / r_d
int | rd_d_cp = r_d / c_p
int | radius = 6371.
float | R = 8.314

## Detailed Description

    Physics calculations with defined constants

    This class contains various physics calculations, implemented as class
    methods, which use defined physical constants. It can be subclassed with
    different constants to suit processing of data related to models with
    constants defined otherwise.

## Member Function Documentation

## ◆ barom_lapse0_gp()

def palmmeteo.library.PalmPhysics.barom_lapse0_gp | ( |  | cls,
|  |  | gp0,
|  |  | p,
|  |  | p0,
|  |  | t0
| ) |  |

    Converts geopotential based on pressure using barometric equation

## ◆ barom_lapse0_pres()

def palmmeteo.library.PalmPhysics.barom_lapse0_pres | ( |  | cls,
|  |  | p0,
|  |  | gp,
|  |  | gp0,
|  |  | t0
| ) |  |

    Converts pressure based on geopotential using barometric equation

## ◆ barom_ptn_pres()

def palmmeteo.library.PalmPhysics.barom_ptn_pres | ( |  | cls,
|  |  | p0,
|  |  | z,
|  |  | t0
| ) |  |

    Compute the barometric formula for 1-D array arguments.

    The calculation is based on the assumption of a polytropic atmosphere
    and neutral stratification, where the temperature lapse rate is g/cp.

## ◆ exner()

def palmmeteo.library.PalmPhysics.exner | ( |  | cls,
|  |  | p
| ) |  |

    Exner function

## ◆ exner_inv()

def palmmeteo.library.PalmPhysics.exner_inv | ( |  | cls,
|  |  | p
| ) |  |

    Reciprocal of the Exner function

## Member Data Documentation

## ◆ c_p

int palmmeteo.library.PalmPhysics.c_p = 1005.
| static

## ◆ cp_d_rd

int palmmeteo.library.PalmPhysics.cp_d_rd = c_p / r_d
| static

## ◆ d_p0

int palmmeteo.library.PalmPhysics.d_p0 = 1e-5
| static

## ◆ g

float palmmeteo.library.PalmPhysics.g = 9.81
| static

## ◆ g_d_cp

float palmmeteo.library.PalmPhysics.g_d_cp = g / c_p
| static

## ◆ p0

int palmmeteo.library.PalmPhysics.p0 = 1e5
| static

## ◆ R

float palmmeteo.library.PalmPhysics.R = 8.314
| static

## ◆ r_d

int palmmeteo.library.PalmPhysics.r_d = 287.
| static

## ◆ radius

int palmmeteo.library.PalmPhysics.radius = 6371.
| static

## ◆ rd_d_cp

int palmmeteo.library.PalmPhysics.rd_d_cp = r_d / c_p
| static

## ◆ sigma_sb

float palmmeteo.library.PalmPhysics.sigma_sb = 5.67037e-08
| static

The documentation for this class was generated from the following file:

- palmmeteo/library.py